<?php
	abstract class Vue {
		/* array(<URL>, <Title>) */
		/* Page titles are passed through STR::html() */
		private $pages = array(array('Home', 'Home'),
							   array('Session', 'Sessions'),
							   array('Users', 'Users'),
							   array('Str', 'Strings'));
		
		// To be implemented in child classes
		protected function authorize($post) { return true; }
		protected function handleGET() {}
		protected function handlePOST() {}
		abstract protected function render();
		
		final function handle() {
			$method = $_SERVER['REQUEST_METHOD'];
			if (!$this->authorize($method === 'POST'))
				return (new Vue403())->handle();
			if ($method === 'GET')
				$this->handleGET();
			if ($method === 'POST')
				$this->handlePOST();
			$this->render();
		}
		
		final protected function renderTitle($title, $menu = true) {
?>
<!doctype html>
<meta content=width=device-width name=viewport />
<link href="<?= htmlspecialchars(preg_replace('@[^/]*$@', '', $_SERVER['SCRIPT_NAME']) . 'style/sheet.css') ?>" rel=stylesheet />
<title><?= htmlspecialchars($title) ?></title>
<?php if ($menu): ?>
<form method=post><table width=100%><tr>
	<td align=left>
		<?= STR::html('Welcome') ?>, <span class=user><?= htmlspecialchars(USERNAME . ' (' . USER . ')') ?></span>.
		<br />
<?php	foreach ($this->pages as list($page, $name)): ?>
		<a href="<?= URL::FullURLHTML(...(array)$page) ?>"><?= STR::html($name) ?></a>
<?php	endforeach; ?>
	</td>
	<td align=right nowrap>
<?php	foreach (STR::get_langs() as $lang): ?>
<?php		if ($lang !== LANG): ?>
		<a href="<?= URL::LangURLHTML($lang) ?>"><?= STR::html($lang) ?></a>
<?php		endif; ?>
<?php	endforeach; ?>
		<button name=_logout><?= STR::html('Logout') ?></button>
	</td>
</tr></table></form>
<?php else: ?>
<table width=100%><tr><td align=right nowrap>
<?php	foreach (STR::get_langs() as $lang): ?>
<?php		if ($lang !== LANG): ?>
	<a href="<?= URL::LangURLHTML($lang) ?>"><?= STR::html($lang) ?></a>
<?php		endif; ?>
<?php	endforeach; ?>
</td></tr></table>
<?php endif; ?>
<hr />
<h1><?= htmlspecialchars($title) ?></h1>
<?php
		}
	}
?>
